summaryrefslogtreecommitdiff
path: root/ace/Init_ACE.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ace/Init_ACE.cpp')
-rw-r--r--ace/Init_ACE.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/ace/Init_ACE.cpp b/ace/Init_ACE.cpp
index d1f098438bc..d58574d07c3 100644
--- a/ace/Init_ACE.cpp
+++ b/ace/Init_ACE.cpp
@@ -6,36 +6,36 @@ ACE_RCSID (ace,
Init_ACE,
"$Id$")
-
-unsigned int ACE::init_fini_count_ = 0;
+// Static data members.
+unsigned int ACE_Init_ACE::init_fini_count_ = 0;
int
-ACE::init (void)
+ACE_Init_ACE::init (void)
{
// Don't use ACE_TRACE, because Object_Manager might not have been
// instantiated yet.
- // ACE_TRACE ("ACE::init");
+ // ACE_TRACE ("ACE_Init_ACE::init");
- ++ACE::init_fini_count_;
+ ++init_fini_count_;
return ACE_Object_Manager::instance ()->init ();
}
int
-ACE::fini (void)
+ACE_Init_ACE::fini (void)
{
- ACE_TRACE ("ACE::fini");
+ ACE_TRACE ("ACE_Init_ACE::fini");
- if (ACE::init_fini_count_ > 0)
+ if (init_fini_count_ > 0)
{
- if (--ACE::init_fini_count_ == 0)
+ if (--init_fini_count_ == 0)
return ACE_Object_Manager::instance ()->fini ();
else
// Wait for remaining fini () calls.
return 1;
}
else
// More ACE::fini () calls than ACE::init () calls. Bad
// application!
return -1;
}
@@ -6,36 +6,36 @@ ACE_RCSID (ace,
}
else
- // More ACE::fini () calls than ACE::init () calls. Bad
+ // More ACE_Init_ACE::fini () calls than ACE_Init_ACE::init () calls. Bad
// application!
return -1;